@@ -53,6 +53,7 @@
 #include "kipmsglogger.h"
 #include "kipmsgevent.h"
 #include "openconfirm.h"
+#include "networkconfig.h"
 
 #define POLLING_INTERVAL_MSEC 500
 
@@ -182,9 +183,10 @@ kipmsgWidget::kipmsgWidget(QWidget* parent, const char* name, WFlags fl)
 	IpMsgAgent = IpMessengerAgent::GetInstance();
 	IpMsgAgent->SetEventObject( new KIpMsgEvent() );
 	IpMsgAgent->SetSortHostListComparator( new KIpMsgHostListComparator() );
-	IpMsgAgent->SetAbortDownloadAtFileChanged( KIpMsgSettings::notPermitedIfModified() );
+	IpMsgAgent->setAbortDownloadAtFileChanged( KIpMsgSettings::notPermitedIfModified() );
 	IpMsgAgent->setIsDialup( KIpMsgSettings::connectDialup() );
 	IpMsgAgent->setSaveRecievedMessage( false );
+	IpMsgAgent->setNoSendMessageOnEncryptionFailed( KIpMsgSettings::noSendOnEncryptionFaild() );
 
 	QStringList broadcastNetworkAddress = KIpMsgSettings::broadcastNetworkAddress();
 	for( QStringList::iterator it = broadcastNetworkAddress.begin(); it != broadcastNetworkAddress.end(); it++){
@@ -192,7 +194,7 @@ kipmsgWidget::kipmsgWidget(QWidget* parent, const char* name, WFlags fl)
 		IpMsgAgent->AddBroadcastAddress( broadcastAddress.data() );
 	}
 
-	IpMsgAgent->StartNetwork();
+	IpMsgAgent->StartNetwork( NetworkConfig::getSpecifyNics() );
 
     MainPopup = new KPopupMenu(this);
 	AbsencePopup = new KPopupMenu(this);
@@ -265,7 +267,7 @@ void kipmsgWidget::rebuildMenu()
 	} else {
 		iconImage.load( KIpMsgSettings::absenceIconFileName() );
 	}
-	MainPopup->insertItem( iconImage, tr2i18n("Absense mode"), AbsencePopup );
+	MainPopup->insertItem( iconImage, tr2i18n("Absence mode"), AbsencePopup );
 	if ( IpMsgAgent->IsAbsence() ){
 		MainPopup->insertSeparator();
 		MainPopup->insertItem( tr2i18n("Reset absence mode") + "(" + modeName + ")", this, SLOT( slotResetAbsenceModeClicked( void ) ) );
@@ -360,8 +362,9 @@ void kipmsgWidget::mousePressEvent( QMouseEvent *e )
 	if(e->button() == LeftButton ){
 		if ( kipmsgWidget::isRecievedOnNonePopup() ) {
 			KIpMsgEvent *evt = dynamic_cast<KIpMsgEvent *>(IpMsgAgent->GetEventObject());
-			if ( evt != NULL ) {
+			if ( evt != NULL && evt->GetRecievedMessageCount() > 0 ) {
 				evt->ShowHiddenRecieveMsg();
+				return;
 			}
 		}
 		if ( KIpMsgSettings::openBySingleClick() ) {
